pub enum LinkFileError {
IoError(String, Error),
FailedToOpenSourceFile(Error),
FailedToReadSourceFile(Error),
FailedToReadSymlink(Error),
FailedToLink(LinkMethod, Error),
FailedToReadSourceFileMetadata(Error),
FailedToOpenDestinationFile(Error),
FailedToUpdateDestinationFilePermissions(Error),
FailedToUpdateDestinationFileTimestamps(Error),
FailedToSignAppleBinary,
MissingPythonInfo,
FailedToComputeSha(Error),
}Expand description
Errors that can occur when calling link_file.
Variants
IoError(String, Error)
An IO error occurred.
FailedToOpenSourceFile(Error)
The source file could not be opened.
FailedToReadSourceFile(Error)
The source file could not be opened.
FailedToReadSymlink(Error)
Unable to read the contents of a symlink
FailedToLink(LinkMethod, Error)
Linking the file from the source to the destination failed.
FailedToReadSourceFileMetadata(Error)
The source file metadata could not be read.
FailedToOpenDestinationFile(Error)
The destination file could not be opened.
FailedToUpdateDestinationFilePermissions(Error)
The permissions could not be updated on the destination file.
FailedToUpdateDestinationFileTimestamps(Error)
The atime/mtime could not be updated on the destination file.
FailedToSignAppleBinary
The binary (dylib or executable) could not be signed (codesign -f -s -) on macOS ARM64 (Apple Silicon).
MissingPythonInfo
No Python version was specified when installing a noarch package.
FailedToComputeSha(Error)
The hash of the file could not be computed.