Enum LinkMethod

pub enum LinkMethod {
    Reflink,
    Hardlink,
    Softlink,
    Copy,
    Patched(FileMode),
}
Describes the method to “link” a file from the source directory (or the cache directory) to the destination directory.

Variants

A ref link is created from the cache to the destination. This ensures that the file does not take up more disk-space and that the file is not accidentally modified in the cache.

A hard link is created from the cache to the destination. This ensures that the file does not take up more disk-space but has the downside that if the file is accidentally modified it is also modified in the cache.

A soft link is created. The link does not refer to the original file in the cache directory but instead it points to another file in the destination.



Copy

A copy of a file is created from a file in the cache directory to a file in the destination directory.



Patched(FileMode)

A copy of a file is created and it is also patched.