pub fn copy_and_replace_placeholders(
source_bytes: &[u8],
destination: impl Write,
prefix_placeholder: &str,
target_prefix: &str,
target_platform: &Platform,
file_mode: FileMode,
) -> Result<(), Error>Expand description
Given the contents of a file copy it to the destination and in the process replace the
prefix_placeholder text with the target_prefix text.
This switches to more specialized functions that handle the replacement of either
textual and binary placeholders, the [FileMode] enum switches between the two functions.
See both copy_and_replace_cstring_placeholder and copy_and_replace_textual_placeholder